=== modified file 'bzrlib/commit.py'
--- bzrlib/commit.py	2009-03-27 04:36:58 +0000
+++ bzrlib/commit.py	2009-03-31 20:34:33 +0000
@@ -62,6 +62,7 @@
     revision,
     trace,
     tree,
+    xml_serializer,
     )
 from bzrlib.branch import Branch
 import bzrlib.config
@@ -607,14 +608,7 @@
         # serialiser not by commit. Then we can also add an unescaper
         # in the deserializer and start roundtripping revision messages
         # precisely. See repository_implementations/test_repository.py
-
-        # Python strings can include characters that can't be
-        # represented in well-formed XML; escape characters that
-        # aren't listed in the XML specification
-        # (http://www.w3.org/TR/REC-xml/#NT-Char).
-        self.message, escape_count = re.subn(
-            u'[^\x09\x0A\x0D\u0020-\uD7FF\uE000-\uFFFD]+',
-            lambda match: match.group(0).encode('unicode_escape'),
+        self.message, escape_count = xml_serializer.escape_invalid_chars(
             self.message)
         if escape_count:
             self.reporter.escaped(escape_count, self.message)

=== modified file 'bzrlib/xml_serializer.py'
--- bzrlib/xml_serializer.py	2009-03-23 14:59:43 +0000
+++ bzrlib/xml_serializer.py	2009-03-31 20:34:33 +0000
@@ -185,3 +185,19 @@
 format_registry.register_lazy('6', 'bzrlib.xml6', 'serializer_v6')
 format_registry.register_lazy('7', 'bzrlib.xml7', 'serializer_v7')
 format_registry.register_lazy('8', 'bzrlib.xml8', 'serializer_v8')
+
+
+def escape_invalid_chars(message):
+    """Escape the XML-invalid characters in a commit message.
+
+    :param message: Commit message to escape
+    :param count: Number of characters that were escaped
+    """
+    # Python strings can include characters that can't be
+    # represented in well-formed XML; escape characters that
+    # aren't listed in the XML specification
+    # (http://www.w3.org/TR/REC-xml/#NT-Char).
+    return re.subn(u'[^\x09\x0A\x0D\u0020-\uD7FF\uE000-\uFFFD]+',
+            lambda match: match.group(0).encode('unicode_escape'),
+            message)
+

